@@ -23,7 +23,7 @@ from pandas.core.dtypes.common import (
 )
 from pandas._libs.lib import no_default
 from pandas._typing import IndexKeyFunc
-from pandas.util._decorators import doc
+
 import sys
 from typing import Union, Optional
 import warnings
@@ -32,53 +32,10 @@ from modin.utils import _inherit_docstrings, to_pandas, Engine
 from modin.config import IsExperimental, PersistentPickle
 from .base import BasePandasDataset, _ATTRS_NO_LOOKUP
 from .iterator import PartitionIterator
-from .utils import from_pandas, is_scalar
+from .utils import from_pandas, is_scalar, _doc_binary_op
 from .accessor import CachedAccessor, SparseAccessor
 from . import _update_engine
 
-_doc_binary_operation = """
-Return {operation} of Series and `{other}` (binary operator `{bin_op}`).
-
-Parameters
-----------
-{other} : Series or scalar value
-    The second operand to perform computation.
-
-Returns
--------
-{returns}
-"""
-
-
-def _doc_binary_op(operation, bin_op, other="right", returns="Series"):
-    """
-    Return callable documenting `Series` binary operator.
-
-    Parameters
-    ----------
-    operation : str
-        Operation name.
-    bin_op : str
-        Binary operation name.
-    other : str, default: 'right'
-        The second operand name.
-    returns : str, default: 'Series'
-        Type of returns.
-
-    Returns
-    -------
-    callable
-    """
-    doc_op = doc(
-        _doc_binary_operation,
-        operation=operation,
-        other=other,
-        bin_op=bin_op,
-        returns=returns,
-    )
-
-    return doc_op
-
 
 @_inherit_docstrings(
     pandas.Series, excluded=[pandas.Series.__init__], apilink="pandas.Series"
@@ -125,6 +82,9 @@ class Series(BasePandasDataset):
         fastpath=False,
         query_compiler=None,
     ):
+        # Siblings are other dataframes that share the same query compiler. We
+        # use this list to update inplace when there is a shallow copy.
+        self._siblings = []
         Engine.subscribe(_update_engine)
         if isinstance(data, type(self)):
             query_compiler = data._query_compiler.copy()
@@ -132,7 +92,7 @@ class Series(BasePandasDataset):
                 if any(i not in data.index for i in index):
                     raise NotImplementedError(
                         "Passing non-existent columns or index values to constructor "
-                        "not yet implemented."
+                        + "not yet implemented."
                     )
                 query_compiler = data.loc[index]._query_compiler
         if query_compiler is None:
@@ -201,18 +161,18 @@ class Series(BasePandasDataset):
     def __add__(self, right):
         return self.add(right)
 
-    @_doc_binary_op(operation="addition", bin_op="add", other="left")
+    @_doc_binary_op(operation="addition", bin_op="add", right="left")
     def __radd__(self, left):
         return self.add(left)
 
-    @_doc_binary_op(operation="union", bin_op="and", other="other")
+    @_doc_binary_op(operation="union", bin_op="and", right="other")
     def __and__(self, other):
         if isinstance(other, (list, np.ndarray, pandas.Series)):
             return self._default_to_pandas(pandas.Series.__and__, other)
         new_self, new_other = self._prepare_inter_op(other)
         return super(Series, new_self).__and__(new_other)
 
-    @_doc_binary_op(operation="union", bin_op="and", other="other")
+    @_doc_binary_op(operation="union", bin_op="and", right="other")
     def __rand__(self, other):
         if isinstance(other, (list, np.ndarray, pandas.Series)):
             return self._default_to_pandas(pandas.Series.__rand__, other)
@@ -324,7 +284,7 @@ class Series(BasePandasDataset):
     @_doc_binary_op(
         operation="integer division and modulo",
         bin_op="divmod",
-        other="left",
+        right="left",
         returns="tuple of two Series",
     )
     def __rdivmod__(self, left):
@@ -397,7 +357,7 @@ class Series(BasePandasDataset):
     def __mod__(self, right):
         return self.mod(right)
 
-    @_doc_binary_op(operation="modulo", bin_op="mod", other="left")
+    @_doc_binary_op(operation="modulo", bin_op="mod", right="left")
     def __rmod__(self, left):
         return self.rmod(left)
 
@@ -405,32 +365,32 @@ class Series(BasePandasDataset):
     def __mul__(self, right):
         return self.mul(right)
 
-    @_doc_binary_op(operation="multiplication", bin_op="mul", other="left")
+    @_doc_binary_op(operation="multiplication", bin_op="mul", right="left")
     def __rmul__(self, left):
         return self.rmul(left)
 
-    @_doc_binary_op(operation="disjunction", bin_op="or", other="other")
+    @_doc_binary_op(operation="disjunction", bin_op="or", right="other")
     def __or__(self, other):
         if isinstance(other, (list, np.ndarray, pandas.Series)):
             return self._default_to_pandas(pandas.Series.__or__, other)
         new_self, new_other = self._prepare_inter_op(other)
         return super(Series, new_self).__or__(new_other)
 
-    @_doc_binary_op(operation="disjunction", bin_op="or", other="other")
+    @_doc_binary_op(operation="disjunction", bin_op="or", right="other")
     def __ror__(self, other):
         if isinstance(other, (list, np.ndarray, pandas.Series)):
             return self._default_to_pandas(pandas.Series.__ror__, other)
         new_self, new_other = self._prepare_inter_op(other)
         return super(Series, new_self).__ror__(new_other)
 
-    @_doc_binary_op(operation="exclusive or", bin_op="xor", other="other")
+    @_doc_binary_op(operation="exclusive or", bin_op="xor", right="other")
     def __xor__(self, other):
         if isinstance(other, (list, np.ndarray, pandas.Series)):
             return self._default_to_pandas(pandas.Series.__xor__, other)
         new_self, new_other = self._prepare_inter_op(other)
         return super(Series, new_self).__xor__(new_other)
 
-    @_doc_binary_op(operation="exclusive or", bin_op="xor", other="other")
+    @_doc_binary_op(operation="exclusive or", bin_op="xor", right="other")
     def __rxor__(self, other):
         if isinstance(other, (list, np.ndarray, pandas.Series)):
             return self._default_to_pandas(pandas.Series.__rxor__, other)
@@ -441,7 +401,7 @@ class Series(BasePandasDataset):
     def __pow__(self, right):
         return self.pow(right)
 
-    @_doc_binary_op(operation="exponential power", bin_op="pow", other="left")
+    @_doc_binary_op(operation="exponential power", bin_op="pow", right="left")
     def __rpow__(self, left):
         return self.rpow(left)
 
@@ -453,8 +413,8 @@ class Series(BasePandasDataset):
         -------
         str
         """
-        num_rows = pandas.get_option("max_rows") or 60
-        num_cols = pandas.get_option("max_columns") or 20
+        num_rows = pandas.get_option("display.max_rows") or 60
+        num_cols = pandas.get_option("display.max_columns") or 20
         temp_df = self._build_repr_df(num_rows, num_cols)
         if isinstance(temp_df, pandas.DataFrame) and not temp_df.empty:
             temp_df = temp_df.iloc[:, 0]
@@ -520,7 +480,7 @@ class Series(BasePandasDataset):
     def __sub__(self, right):
         return self.sub(right)
 
-    @_doc_binary_op(operation="subtraction", bin_op="sub", other="left")
+    @_doc_binary_op(operation="subtraction", bin_op="sub", right="left")
     def __rsub__(self, left):
         return self.rsub(left)
 
@@ -528,7 +488,7 @@ class Series(BasePandasDataset):
     def __truediv__(self, right):
         return self.truediv(right)
 
-    @_doc_binary_op(operation="floating division", bin_op="truediv", other="left")
+    @_doc_binary_op(operation="floating division", bin_op="truediv", right="left")
     def __rtruediv__(self, left):
         return self.rtruediv(left)
 
@@ -543,7 +503,7 @@ class Series(BasePandasDataset):
         """
         Return Series as ndarray or ndarray-like depending on the dtype.
         """
-        return super(Series, self).to_numpy().flatten()
+        return self.to_numpy()
 
     def add(self, other, level=None, fill_value=None, axis=0):  # noqa: PR01, RT01, D200
         """
@@ -576,7 +536,7 @@ class Series(BasePandasDataset):
 
         bad_type_msg = (
             'cannot concatenate object of type "{}"; only pd.Series, '
-            "pd.DataFrame, and pd.Panel (deprecated) objs are valid"
+            + "pd.DataFrame, and pd.Panel (deprecated) objs are valid"
         )
         if isinstance(to_append, list):
             if not all(isinstance(o, BasePandasDataset) for o in to_append):
@@ -642,7 +602,11 @@ class Series(BasePandasDataset):
         else:
             return Series(query_compiler=query_compiler)
 
-    def aggregate(self, func=None, axis=0, *args, **kwargs):
+    def aggregate(self, func=None, axis=0, *args, **kwargs):  # noqa: PR01, RT01, D200
+        """
+        Aggregate using one or more operations over the specified axis.
+        """
+
         def error_raiser(msg, exception):
             """Convert passed exception to the same type as pandas do and raise it."""
             # HACK: to concord with pandas error types by replacing all of the
@@ -1024,7 +988,7 @@ class Series(BasePandasDataset):
         if isinstance(value, BasePandasDataset) and not isinstance(value, Series):
             raise TypeError(
                 '"value" parameter must be a scalar, dict or Series, but '
-                'you passed a "{0}"'.format(type(value).__name__)
+                + f'you passed a "{type(value).__name__}"'
             )
         return super(Series, self)._fillna(
             squeeze_self=True,
@@ -1074,7 +1038,7 @@ class Series(BasePandasDataset):
             warnings.warn(
                 (
                     "The `squeeze` parameter is deprecated and "
-                    "will be removed in a future version."
+                    + "will be removed in a future version."
                 ),
                 FutureWarning,
                 stacklevel=2,
@@ -1161,6 +1125,26 @@ class Series(BasePandasDataset):
             skipna = True
         return super(Series, self).idxmin(axis=axis, skipna=skipna, *args, **kwargs)
 
+    def info(
+        self,
+        verbose: "bool | None" = None,
+        buf: "IO[str] | None" = None,
+        max_cols: "int | None" = None,
+        memory_usage: "bool | str | None" = None,
+        show_counts: "bool" = True,
+    ):  # noqa: PR01, RT01, D200
+        """
+        Print a concise summary of a Series.
+        """
+        return self._default_to_pandas(
+            pandas.Series.info,
+            verbose=verbose,
+            buf=buf,
+            max_cols=max_cols,
+            memory_usage=memory_usage,
+            show_counts=show_counts,
+        )
+
     def interpolate(
         self,
         method="linear",
@@ -1218,7 +1202,12 @@ class Series(BasePandasDataset):
         return self.index
 
     def kurt(
-        self, axis=None, skipna=None, level=None, numeric_only=None, **kwargs
+        self,
+        axis: "Axis | None | NoDefault" = no_default,
+        skipna=True,
+        level=None,
+        numeric_only=None,
+        **kwargs,
     ):  # noqa: PR01, RT01, D200
         """
         Return unbiased kurtosis over requested axis.
@@ -1262,6 +1251,27 @@ class Series(BasePandasDataset):
             )
         )
 
+    def mask(
+        self,
+        cond,
+        other=np.nan,
+        inplace=False,
+        axis=None,
+        level=None,
+        errors=no_default,
+        try_cast=no_default,
+    ):
+        return self._default_to_pandas(
+            pandas.Series.mask,
+            cond,
+            other=other,
+            inplace=inplace,
+            axis=axis,
+            level=level,
+            errors=errors,
+            try_cast=try_cast,
+        )
+
     def memory_usage(self, index=True, deep=False):  # noqa: PR01, RT01, D200
         """
         Return the memory usage of the Series.
@@ -1409,7 +1419,7 @@ class Series(BasePandasDataset):
     def prod(
         self,
         axis=None,
-        skipna=None,
+        skipna=True,
         level=None,
         numeric_only=None,
         min_count=0,
@@ -1419,8 +1429,7 @@ class Series(BasePandasDataset):
         Return the product of the values over the requested `axis`.
         """
         axis = self._get_axis_number(axis)
-        if skipna is None:
-            skipna = True
+        validate_bool_kwarg(skipna, "skipna", none_allowed=False)
         if level is not None:
             if (
                 not self._query_compiler.has_multiindex(axis=axis)
@@ -1476,10 +1485,19 @@ class Series(BasePandasDataset):
 
         return data
 
-    def reindex(self, index=None, **kwargs):  # noqa: PR01, RT01, D200
+    def reindex(self, *args, **kwargs):  # noqa: PR01, RT01, D200
         """
         Conform Series to new index with optional filling logic.
         """
+        if args:
+            if len(args) > 1:
+                raise TypeError("Only one positional argument ('index') is allowed")
+            if "index" in kwargs:
+                raise TypeError(
+                    "'index' passed as both positional and keyword argument"
+                )
+            kwargs.update({"index": args[0]})
+        index = kwargs.pop("index", None)
         method = kwargs.pop("method", None)
         level = kwargs.pop("level", None)
         copy = kwargs.pop("copy", True)
@@ -1489,7 +1507,7 @@ class Series(BasePandasDataset):
         if kwargs:
             raise TypeError(
                 "reindex() got an unexpected keyword "
-                'argument "{0}"'.format(list(kwargs.keys())[0])
+                + f'argument "{list(kwargs.keys())[0]}"'
             )
         return super(Series, self).reindex(
             index=index,
@@ -1543,16 +1561,20 @@ class Series(BasePandasDataset):
         return self.__constructor__(query_compiler=self._query_compiler.repeat(repeats))
 
     def reset_index(
-        self, level=None, drop=False, name=None, inplace=False
+        self, level=None, drop=False, name=no_default, inplace=False
     ):  # noqa: PR01, RT01, D200
         """
         Generate a new Series with the index reset.
         """
+        if name is no_default:
+            # For backwards compatibility, keep columns as [0] instead of
+            #  [None] when self.name is None
+            name = 0 if self.name is None else self.name
+
         if drop and level is None:
             new_idx = pandas.RangeIndex(len(self.index))
             if inplace:
                 self.index = new_idx
-                self.name = name or self.name
             else:
                 result = self.copy()
                 result.index = new_idx
@@ -1563,8 +1585,7 @@ class Series(BasePandasDataset):
             )
         else:
             obj = self.copy()
-            if name is not None:
-                obj.name = name
+            obj.name = name
             from .dataframe import DataFrame
 
             return DataFrame(obj).reset_index(level=level, drop=drop, inplace=inplace)
@@ -1653,11 +1674,11 @@ class Series(BasePandasDataset):
     def replace(
         self,
         to_replace=None,
-        value=None,
+        value=no_default,
         inplace=False,
         limit=None,
         regex=False,
-        method="pad",
+        method: "str | NoDefault" = no_default,
     ):  # noqa: PR01, RT01, D200
         """
         Replace values given in `to_replace` with `value`.
@@ -1770,7 +1791,7 @@ class Series(BasePandasDataset):
     def sum(
         self,
         axis=None,
-        skipna=None,
+        skipna=True,
         level=None,
         numeric_only=None,
         min_count=0,
@@ -1780,8 +1801,7 @@ class Series(BasePandasDataset):
         Return the sum of the values.
         """
         axis = self._get_axis_number(axis)
-        if skipna is None:
-            skipna = True
+        validate_bool_kwarg(skipna, "skipna", none_allowed=False)
         if numeric_only is True:
             raise NotImplementedError("Series.sum does not implement numeric_only")
         if level is not None:
@@ -1843,15 +1863,21 @@ class Series(BasePandasDataset):
         """
         return self._default_to_pandas("to_dict", into=into)
 
-    def to_frame(self, name=None):  # noqa: PR01, RT01, D200
+    def to_frame(
+        self, name: "Hashable" = no_default
+    ) -> "DataFrame":  # noqa: PR01, RT01, D200
         """
         Convert Series to {label -> value} dict or dict-like object.
         """
         from .dataframe import DataFrame
 
+        if name is None:
+            name = no_default
+
         self_cp = self.copy()
-        if name is not None:
+        if name is not no_default:
             self_cp.name = name
+
         return DataFrame(self_cp)
 
     def to_list(self):  # noqa: RT01, D200
@@ -2011,11 +2037,11 @@ class Series(BasePandasDataset):
     def where(
         self,
         cond,
-        other=np.nan,
+        other=no_default,
         inplace=False,
         axis=None,
         level=None,
-        errors="raise",
+        errors=no_default,
         try_cast=no_default,
     ):  # noqa: PR01, RT01, D200
         """
